@@ -3,11 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
-use Music::Scales qw(get_scale_notes);
+use Music::Scales qw(get_scale_notes is_scale);
 use Music::Note;
 use Moo;
 use strictures 2;
@@ -23,7 +23,7 @@ has scale_note => (
 
 has scale_name => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a valid string" unless $_[0] =~ /^\w+$/ },
+    isa     => sub { die "$_[0] is not a valid scale name" unless is_scale($_[0]) },
     default => sub { 'chromatic' },
 );
 
@@ -117,7 +117,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -128,12 +128,12 @@ version 0.0103
   # Chromatic
   my $md = Music::MelodicDevice::Inversion->new;
   my $intervals = $md->intervals(\@notes); # [4, -2, 5, 5]
-  my $inv = $md->invert('C4', \@notes); # [C4, G#3, A#3, F3, C3]
+  my $inverted = $md->invert('C4', \@notes); # [C4, G#3, A#3, F3, C3]
 
   # Diatonic
   $md = Music::MelodicDevice::Inversion->new(scale_name => 'major');
   $intervals = $md->intervals(\@notes); # [2, -1, 3, 3]
-  $inv = $md->invert('C4', \@notes); # [C4, A3, B3, F3, C3]
+  $inverted = $md->invert('C4', \@notes); # [C4, A3, B3, F3, C3]
 
 =head1 DESCRIPTION
 
